@@ -1,6 +1,8 @@
 from client import DoubanClient
 
-client = DoubanClient('373512566@qq.com','122126382')
+c1 = DoubanClient('tianyu0915@126.com','ty283406767')
+print c1.login()
+
 
 #print 'x',client.reply_topic('http://www.douban.com/group/topic/39324575/','101001001011101010010')
 
